@@ -1,5 +1,6 @@
 from django.conf import settings
 from django.db import models
+from djangoldp_i18n.views import I18nLDPViewSet
 
 from djangoldp.models import Model
 
@@ -14,6 +15,7 @@ class Skill(Model):
         authenticated_perms = ['inherit', 'add', 'change', 'delete']
         container_path = 'skills/'
         rdf_type = 'hd:skill'
+        view_set = I18nLDPViewSet
 
 
     def __str__(self):
